@@ -8,7 +8,6 @@ use CGI;
 use LWP::UserAgent;
 use POSIX ();
 use SlapbirdAPM::CGI::DBIx::Tracer;
-use IO::String;
 use IO::Tee;
 use IO::Pipe;
 use Time::HiRes;
@@ -19,11 +18,10 @@ use JSON;
 
 $Carp::Internal{__PACKAGE__} = 1;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my %request_headers;
 our $cgi = CGI->new();
-our $res = IO::String->new;
 our $handler;
 our $start_time;
 our @error;
